'use client';

import { useNavigate } from 'react-router-dom';
import { useState } from 'react';
import { Button } from '@/components/ui/button';
import { DashboardLayout } from '@/components/layouts/dashboard-layout';
import * as AlertDialog from '@radix-ui/react-alert-dialog';
import { motion, AnimatePresence } from 'framer-motion';
import { cn } from '@/lib/utils';
import { useToast } from '@/components/ui/use-toast';
import { deleteAccount } from './api';

export default function DeleteAccount() {
  const navigate = useNavigate();
  const [isDeleting, setIsDeleting] = useState(false);
  const [showDialog, setShowDialog] = useState(false);

  const { toast } = useToast();

  const handleDeleteAccount = async () => {
    setIsDeleting(true);

    try {
      const success = await deleteAccount(toast, navigate);

      localStorage.removeItem('auth_token');

      if (success) {
        navigate('/login');
      }
    } catch (error) {
      console.error('Failed to delete account:', error);
    } finally {
      setIsDeleting(false);
    }
  };

  return (
    <DashboardLayout>
      <motion.main
        initial={{ opacity: 0 }}
        animate={{ opacity: 1 }}
        transition={{ duration: 0.3 }}
        className="min-h-[80vh] flex items-center justify-center px-4"
      >
        <div className="w-full max-w-md">
          <motion.div 
            initial={{ y: 20, opacity: 0 }}
            animate={{ y: 0, opacity: 1 }}
            transition={{ delay: 0.1, duration: 0.4 }}
            className="bg-white dark:bg-gray-900 rounded-xl border-2 shadow-lg p-6 space-y-6"
          >
            <div className="space-y-4">
              <h1 className="text-2xl font-medium text-gray-900 dark:text-gray-50">
                Permanently Delete My Account
              </h1>
              <p className="text-sm">
                Are you sure you want to permanently delete your account?
              </p>
            </div>

            <div className="space-y-6 px-4">
              <div className="space-y-1">
                {[
                  'All API Keys will be deleted',
                  'Your account information will be deleted',
                  'Your apps will stop working'
                ].map((item) => (
                  <div  key={item} className="flex items-center gap-2">
                    → {item}
                  </div>
                ))}
              </div>
            </div>

            <p className={cn(
                "p-2 font-regular  rounded-md text-sm w-full mx-auto",
                "bg-red-50 border border-red-200 dark:bg-red-900/20 dark:border-red-900/40",
                "text-red-700 dark:text-red-500"
              )}>
                Once you delete your account, all of your data will be permanently removed. This action cannot be undone.
              </p>

              <Button
                variant="destructive"
                size="lg"
                onClick={() => setShowDialog(true)}
                disabled={isDeleting}
                className="w-full transition-all"
              >
                <span className="flex items-center justify-center gap-2">
                  {isDeleting ? 'Deleting Account...' : 'Delete Account'}
                </span>
              </Button>

              <p className="text-sm text-center text-gray-500 dark:text-gray-400">
                Need assistance?{' '}
                <a 
                  href="https://anyparser.com/contact/" 
                  className="text-blue-500 hover:text-blue-600 dark:text-blue-400 dark:hover:text-blue-300"
                >
                  Contact Us
                </a>
              </p>

          </motion.div>
        </div>

        <AnimatePresence>
          {showDialog && (
            <AlertDialog.Root open={showDialog} onOpenChange={setShowDialog}>
              <AlertDialog.Portal forceMount>
                <AlertDialog.Overlay asChild>
                  <motion.div
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 1 }}
                    exit={{ opacity: 0 }}
                    transition={{ duration: 0.2 }}
                    className="fixed inset-0 bg-black/30 backdrop-blur-sm z-50"
                  />
                </AlertDialog.Overlay>
                <AlertDialog.Content asChild>
                  <motion.div
                    initial={{ opacity: 0, scale: 0.95 }}
                    animate={{ opacity: 1, scale: 1 }}
                    exit={{ opacity: 0, scale: 0.95 }}
                    transition={{ duration: 0.2 }}
                    className="fixed left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 w-full max-w-sm bg-white dark:bg-gray-900 rounded-2xl shadow-xl p-6 z-50"
                  >
                    <AlertDialog.Title className="text-lg font-medium text-gray-900 dark:text-gray-50 mb-2">
                      Are you absolutely sure?
                    </AlertDialog.Title>
                    <AlertDialog.Description className="text-sm text-gray-600 dark:text-gray-400 mb-6">
                      This will permanently delete your account and remove all associated data. This action cannot be undone.
                    </AlertDialog.Description>
                    <div className="flex justify-end gap-3">
                      <AlertDialog.Cancel asChild>
                        <Button variant="outline" size="sm">
                          Cancel
                        </Button>
                      </AlertDialog.Cancel>
                      <AlertDialog.Action asChild>
                        <Button 
                          variant="destructive" 
                          size="sm"
                          onClick={handleDeleteAccount}
                          disabled={isDeleting}
                        >
                          {isDeleting ? 'Deleting...' : 'Delete Account'}
                        </Button>
                      </AlertDialog.Action>
                    </div>
                  </motion.div>
                </AlertDialog.Content>
              </AlertDialog.Portal>
            </AlertDialog.Root>
          )}
        </AnimatePresence>
      </motion.main>
    </DashboardLayout>
  );
} 